@@ -9,6 +9,7 @@ use {
 
 #[derive(Accounts)]
 #[instruction(
+    owner: Pubkey,
     namespace: String,
     bump: u8,
 )]
@@ -17,17 +18,17 @@ pub struct CreateIndex<'info> {
         init, 
         seeds = [
             state::SEED_INDEX, 
-            owner.key().as_ref(), 
+            owner.as_ref(), 
             namespace.as_ref()
         ], 
         bump = bump, 
-        payer = owner, 
+        payer = signer, 
         space = 8 + size_of::<state::Index>()
     )]
     pub index: Account<'info, state::Index>,
 
     #[account(mut)]
-    pub owner: Signer<'info>,
+    pub signer: Signer<'info>,
     
     #[account(address = system_program::ID)]
     pub system_program: Program<'info, System>,
@@ -35,17 +36,17 @@ pub struct CreateIndex<'info> {
 
 pub fn handler(
     ctx: Context<CreateIndex>, 
+    owner: Pubkey,
     namespace: String,
     bump: u8,
 ) -> ProgramResult {
     // Get accounts.
     let index = &mut ctx.accounts.index;
-    let owner = &ctx.accounts.owner;
 
     // Initialize index account.
-    index.count = 0;
-    index.owner = owner.key();
     index.namespace = namespace;
+    index.owner = owner;
+    index.item_count = 0;
     index.bump = bump;
     
     return Ok(());
