@@ -20,10 +20,10 @@ pub mod indexor {
 
     pub fn create_item(
         ctx: Context<CreateItem>,
-        address: Pubkey,
+        reference: Pubkey,
         item_bump: u8,
         proof_bump: u8,
     ) -> ProgramResult {
-        create_item::handler(ctx, address, item_bump, proof_bump)
+        create_item::handler(ctx, reference, item_bump, proof_bump)
     }
 }
